We provide examples across different ML frameworks and for various tasks in this section.

## Get started

All the examples in this section are self-contained and tested. Feel free to grab one and run:

    python model_server.py

To test the server, we use [`httpie`](https://github.com/httpie/httpie) and [`httpx`](https://github.com/encode/httpx) by default. You can have other choices but if you want to install them:

    pip install httpie httpx
